@@ -135,12 +135,13 @@ use File::Spec;
 use File::Temp qw/tempfile/;
 use Time::HiRes qw/usleep/;
 use POSIX ":sys_wait_h";
+use Fcntl qw/SEEK_SET/;
 
 # VERSION here is for CPAN to parse -- it is the version of the module itself.  But we
 # overload the system VERSION to compare a required version against gnuplot itself, rather
 # than against the module version.
 
-our $VERSION = '1.020';
+our $VERSION = '1.034';
 
 # On install, try to make sure at least this version is present.
 our $GNUPLOT_RECOMMENDED_VERSION = '4.6';  
@@ -191,8 +192,9 @@ sub load_gnuplot {
 Alien::Gnuplot: no executable gnuplot found!  If you have gnuplot,
 you can put its exact location in your GNUPLOT_BINARY environment 
 variable or make sure your PATH contains it.  If you do not have
-gnuplot, you can reinstall Alien::Gnuplot to get it, or get
-it yourself from L<http://www.gnuplot.info>.
+gnuplot, you can reinstall Alien::Gnuplot (and its installation 
+script will try to install gnuplot via one of several standard 
+package managers) or get it yourself from L<http://www.gnuplot.info>.
 };
     }
     
@@ -203,7 +205,7 @@ it yourself from L<http://www.gnuplot.info>.
 # The parent process gives the daughter 2 seconds to report progress, then
 # kills it dead.
     my($pid);
-    my ($undef, $file) = tempfile('gnuplot_test_XXXX');
+    my ($undef, $file) = tempfile();
 
     # Create command file
     open FOO, ">${file}_gzinta";
@@ -239,6 +241,8 @@ it yourself from L<http://www.gnuplot.info>.
 		    open STDOUT, ">$file";
 		    open STDERR, ">&STDOUT";
 		    open STDIN, "<${file}_gzinta";
+		    seek STDIN, 0, SEEK_SET;
+		    no warnings; 
 		    exec($exec_path);
 		    print BAR "Execution of $exec_path failed!\n";
 		    exit(1);
@@ -275,6 +279,7 @@ it yourself from L<http://www.gnuplot.info>.
 # Read what gnuplot had to say, and clean up our mess...
     open FOO, "<$file";
     my @lines = <FOO>;
+    close FOO;
     unlink $file;
     unlink $file."_gzinta";
     
@@ -310,8 +315,8 @@ I could not parse a version number from its output.  Sorry, I give up.
 		$reading_terms = 1;
 	    }
 	} else {
-	    next if($line =~ m/^Press return for more/);
-	    $line =~ m/^\s*(\w+)\s(.*[^\s])\s*$/ || last;
+	    $line =~ s/^Press return for more\:\s*//;
+	    $line =~ m/^\s*(\w+)\s(.*[^\s])\s*$/ || next;
 	    push(@terms, $1);
 	    $terms{$1} = $2;
 	}
